@@ -3,6 +3,7 @@
 
 import json
 import abc
+import time
 from types import SimpleNamespace
 from typing import Any, Dict, List
 
@@ -153,6 +154,9 @@ class TuyaDeviceManager:
         if bizCode == BIZCODE_BIND_USER:
             devId = data['devId']
             devIds = [devId]
+            ## wait for es sync
+            time.sleep(1)
+            
             self._updateDeviceListInfoCache(devIds)
             self._updateDeviceListStatusCache(devIds)
             response = self.getDeviceFunctions(devId)
