@@ -105,7 +105,8 @@ class TuyaOpenAPI():
     def login(self, 
         username: str, 
         password: str,
-        country_code : str = "") -> Dict[str, Any]:
+        country_code : str = '',
+        schema: str = '') -> Dict[str, Any]:
         """
         user login
 
@@ -126,7 +127,7 @@ class TuyaOpenAPI():
                 'username': username,
                 'password': hashlib.md5(password.encode('utf8')).hexdigest(),
                 'country_code': country_code,
-                'schema': 'tuyaSmart'
+                'schema': schema
             })
 
         if not response['success']:
